pub struct MessageRedisCache {
pub content: MessagePushCategory,
}Fields
content: MessagePushCategoryTrait Implementations
Sourceimpl Clone for MessageRedisCache
impl Clone for MessageRedisCache
Sourcefn clone(&self) -> MessageRedisCache
fn clone(&self) -> MessageRedisCache
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageRedisCache
impl Debug for MessageRedisCache
Sourceimpl<'de> Deserialize<'de> for MessageRedisCache
impl<'de> Deserialize<'de> for MessageRedisCache
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromRedisValue for MessageRedisCache
impl FromRedisValue for MessageRedisCache
Sourcefn from_redis_value(v: RedisValue) -> Result<Self, ParsingError>
fn from_redis_value(v: RedisValue) -> Result<Self, ParsingError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_value_ref(v: &Value) -> Result<Self, ParsingError>
fn from_redis_value_ref(v: &Value) -> Result<Self, ParsingError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_value_refs(items: &[Value]) -> Result<Vec<Self>, ParsingError>
fn from_redis_value_refs(items: &[Value]) -> Result<Vec<Self>, ParsingError>
Similar to
from_redis_value_ref but constructs a vector of objects
from another vector of values. This primarily exists internally
to customize the behavior for vectors of tuples.Sourcefn from_redis_values(items: Vec<Value>) -> Result<Vec<Self>, ParsingError>
fn from_redis_values(items: Vec<Value>) -> Result<Vec<Self>, ParsingError>
The same as
from_redis_value_refs, but takes a Vec<Value> instead
of a &[Value].Sourcefn from_each_redis_values(items: Vec<Value>) -> Vec<Result<Self, ParsingError>>
fn from_each_redis_values(items: Vec<Value>) -> Vec<Result<Self, ParsingError>>
The same as
from_redis_values, but returns a result for each
conversion to make handling them case-by-case possible.Sourcefn from_byte_slice(_vec: &[u8]) -> Option<Vec<Self>>
fn from_byte_slice(_vec: &[u8]) -> Option<Vec<Self>>
Convert bytes to a single element vector.
Sourcefn from_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, ParsingError>
fn from_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, ParsingError>
Convert bytes to a single element vector.
Sourceimpl Serialize for MessageRedisCache
impl Serialize for MessageRedisCache
Sourceimpl ToRedisArgs for MessageRedisCache
impl ToRedisArgs for MessageRedisCache
Sourcefn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
fn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
This writes the value into a vector of bytes. Each item
is a single argument. Most items generate a single item. Read more
Sourcefn to_redis_args(&self) -> Vec<Vec<u8>>
fn to_redis_args(&self) -> Vec<Vec<u8>>
This converts the value into a vector of bytes. Each item
is a single argument. Most items generate a vector of a
single item. Read more
Sourcefn describe_numeric_behavior(&self) -> NumericBehavior
fn describe_numeric_behavior(&self) -> NumericBehavior
Returns an information about the contained value with regards
to it’s numeric behavior in a redis context. This is used in
some high level concepts to switch between different implementations
of redis functions (for instance
INCR vs INCRBYFLOAT).Sourcefn num_of_args(&self) -> usize
fn num_of_args(&self) -> usize
Returns the number of arguments this value will generate. Read more