pub struct SysDeptResponse {
pub id: BigIntPrimaryKey,
pub parent_id: BigIntPrimaryKey,
pub ancestors: String,
pub dept_name: String,
pub order_num: Option<i64>,
pub leader: Option<String>,
pub phone: Option<String>,
pub email: Option<String>,
pub status: i8,
pub del_flag: Option<String>,
}Fields
id: BigIntPrimaryKeyparent_id: BigIntPrimaryKeyancestors: Stringdept_name: Stringorder_num: Option<i64>leader: Option<String>phone: Option<String>email: Option<String>status: i8del_flag: Option<String>Trait Implementations
Sourceimpl Clone for SysDeptResponse
impl Clone for SysDeptResponse
Sourcefn clone(&self) -> SysDeptResponse
fn clone(&self) -> SysDeptResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SysDeptResponse
impl Debug for SysDeptResponse
Sourceimpl Default for SysDeptResponse
impl Default for SysDeptResponse
Sourcefn default() -> SysDeptResponse
fn default() -> SysDeptResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SysDeptResponse
impl<'de> Deserialize<'de> for SysDeptResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromQueryResult for SysDeptResponse
impl FromQueryResult for SysDeptResponse
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_nullable(
row: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( row: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>