Module aes_util

Module aes_util 

Functions

aes256_cbc_decrypt
Decrypt a buffer with the given key and iv using AES256/CBC/Pkcs encryption. 解密(data:加密数据;key:密钥(长度为32的字符串);iv:偏移量(长度为16的字符串))
aes256_cbc_encrypt
Encrypt a buffer with the given key and iv using AES256/CBC/Pkcs encryption. 加密(data:加密数据;key:密钥(长度为32的字符串);iv:偏移量(长度为16的字符串))