pub struct SysRoleResponse {
pub role_id: BigIntPrimaryKey,
pub role_name: String,
pub role_key: String,
pub data_scope: String,
pub role_sort: i32,
pub menu_check_strictly: Option<i8>,
pub dept_check_strictly: Option<i8>,
pub status: i8,
pub remark: Option<String>,
pub create_time: DateTime,
pub update_time: Option<DateTime>,
}Fields
role_id: BigIntPrimaryKeyrole_name: Stringrole_key: Stringdata_scope: Stringrole_sort: i32dept_check_strictly: Option<i8>status: i8remark: Option<String>create_time: DateTimeupdate_time: Option<DateTime>Trait Implementations
Sourceimpl Clone for SysRoleResponse
impl Clone for SysRoleResponse
Sourcefn clone(&self) -> SysRoleResponse
fn clone(&self) -> SysRoleResponse
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SysRoleResponse
impl Debug for SysRoleResponse
Sourceimpl<'de> Deserialize<'de> for SysRoleResponse
impl<'de> Deserialize<'de> for SysRoleResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromQueryResult for SysRoleResponse
impl FromQueryResult for SysRoleResponse
Sourcefn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
fn from_query_result(row: &QueryResult, pre: &str) -> Result<Self, DbErr>
Instantiate a Model from a QueryResult Read more
Sourcefn from_query_result_nullable(
row: &QueryResult,
pre: &str,
) -> Result<Self, TryGetError>
fn from_query_result_nullable( row: &QueryResult, pre: &str, ) -> Result<Self, TryGetError>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option Read more
Sourcefn from_query_result_optional(
res: &QueryResult,
pre: &str,
) -> Result<Option<Self>, DbErr>
fn from_query_result_optional( res: &QueryResult, pre: &str, ) -> Result<Option<Self>, DbErr>
Transform the error from instantiating a Model from a QueryResult
and converting it to an Option
Sourcefn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>
fn find_by_statement(stmt: Statement) -> SelectorRaw<SelectModel<Self>>